@@ -1,12 +1,12 @@
 ##' @description
-##' \code{runifDesign} generates a design based on random samples from a multivariate uniform distribution.
+##' \code{runif_design} generates a design based on random samples from a multivariate uniform distribution.
 ##' @rdname design
 ##' @return
-##' \code{runifDesign} returns a data frame with \code{nseq} rows and one column for each variable named in \code{lower} and \code{upper}.
+##' \code{runif_design} returns a data frame with \code{nseq} rows and one column for each variable named in \code{lower} and \code{upper}.
 ##'
 ##' @export
-runifDesign <- function (lower = numeric(0), upper = numeric(0), nseq) {
-  ep <- "runifDesign"
+runif_design <- function (lower = numeric(0), upper = numeric(0), nseq) {
+  ep <- "runif_design"
   if (length(lower)!=length(upper))
     pStop(ep,sQuote("lower")," and ",sQuote("upper")," must have same length.")
   lnames <- names(lower)
