@@ -9,19 +9,12 @@
 ##' @importFrom stats window
 NULL
 
-setGeneric(
-  "window",
-  function (x, ...)
-    standardGeneric("window")
-)
+setGeneric("window")
 
-##' @name window-pomp
 ##' @rdname window
-##' @aliases window window,pomp-method
 ##' @param x a \sQuote{pomp} object or object of class extending \sQuote{pomp}
 ##' @param start,end the left and right ends of the window, in units of time
 ##' @param \dots ignored
-##'
 ##' @export
 setMethod(
   "window",
